@@ -21,9 +21,9 @@ from .renderers import (
 
 SPEC_RENDERERS = swagger_settings.DEFAULT_SPEC_RENDERERS
 UI_RENDERERS = {
-    'swagger': (SwaggerUIRenderer, ReDocRenderer),
-    'redoc': (ReDocRenderer, SwaggerUIRenderer),
-    'redoc-old': (ReDocOldRenderer, ReDocRenderer, SwaggerUIRenderer),
+    "swagger": (SwaggerUIRenderer, ReDocRenderer),
+    "redoc": (ReDocRenderer, SwaggerUIRenderer),
+    "redoc-old": (ReDocOldRenderer, ReDocRenderer, SwaggerUIRenderer),
 }
 
 
@@ -51,18 +51,32 @@ def deferred_never_cache(view_func):
     return _wrapped_view_func
 
 
-def get_schema_view(info=None, url=None, patterns=None, urlconf=None, public=False, validators=None,
-                    generator_class=None, authentication_classes=None, permission_classes=None):
+def get_schema_view(
+    info=None,
+    url=None,
+    patterns=None,
+    urlconf=None,
+    public=False,
+    validators=None,
+    generator_class=None,
+    authentication_classes=None,
+    permission_classes=None,
+):
     """Create a SchemaView class with default renderers and generators.
 
-    :param Info info: information about the API; if omitted, defaults to :ref:`DEFAULT_INFO <default-swagger-settings>`
+    :param Info info: information about the API; if omitted, defaults to
+        :ref:`DEFAULT_INFO <default-swagger-settings>`
     :param str url: same as :class:`.OpenAPISchemaGenerator`
     :param patterns: same as :class:`.OpenAPISchemaGenerator`
     :param urlconf: same as :class:`.OpenAPISchemaGenerator`
-    :param bool public: if False, includes only the endpoints that are accessible by the user viewing the schema
-    :param list validators: a list of validator names to apply; the only allowed value is ``ssv``, for now
-    :param type generator_class: schema generator class to use; should be a subclass of :class:`.OpenAPISchemaGenerator`
-    :param list authentication_classes: authentication classes for the schema view itself
+    :param bool public: if False, includes only the endpoints that are accessible by the
+        user viewing the schema
+    :param list validators: a list of validator names to apply; the only allowed value
+        is ``ssv``, for now
+    :param type generator_class: schema generator class to use; should be a subclass of
+        :class:`.OpenAPISchemaGenerator`
+    :param list authentication_classes: authentication classes for the schema view
+        itself
     :param list permission_classes: permission classes for the schema view itself
     :return: SchemaView class
     :rtype: type[drf_yasg.views.SchemaView]
@@ -77,18 +91,21 @@ def get_schema_view(info=None, url=None, patterns=None, urlconf=None, public=Fal
         _perm_classes = api_settings.DEFAULT_PERMISSION_CLASSES
     info = info or swagger_settings.DEFAULT_INFO
     validators = validators or []
-    _spec_renderers = tuple(renderer.with_validators(validators) for renderer in SPEC_RENDERERS)
+    _spec_renderers = tuple(
+        renderer.with_validators(validators) for renderer in SPEC_RENDERERS
+    )
 
     # optionally copy renderers with the validators that are configured above
     if swagger_settings.USE_COMPAT_RENDERERS:
         warnings.warn(
-            "SwaggerJSONRenderer & SwaggerYAMLRenderer's `format` has changed to not include a `.` prefix, "
-            "please silence this warning by setting `SWAGGER_USE_COMPAT_RENDERERS = False` "
-            "in your Django settings and ensure your application works "
-            "(check your URLCONF and swagger/redoc URLs).",
-            DeprecationWarning)
+            "SwaggerJSONRenderer & SwaggerYAMLRenderer's `format` has changed to not "
+            "include a `.` prefix, please silence this warning by setting "
+            "`SWAGGER_USE_COMPAT_RENDERERS = False` in your Django settings and ensure "
+            "your application works (check your URLCONF and swagger/redoc URLs).",
+            DeprecationWarning,
+        )
         _spec_renderers += tuple(
-            type(cls.__name__, (cls,), {'format': '.' + cls.format})
+            type(cls.__name__, (cls,), {"format": "." + cls.format})
             for cls in _spec_renderers
             if issubclass(cls, (SwaggerJSONRenderer, SwaggerYAMLRenderer))
         )
@@ -102,8 +119,8 @@ def get_schema_view(info=None, url=None, patterns=None, urlconf=None, public=Fal
         permission_classes = _perm_classes
         renderer_classes = _spec_renderers
 
-        def get(self, request, version='', format=None):
-            version = request.version or version or ''
+        def get(self, request, version="", format=None):
+            version = request.version or version or ""
             if isinstance(request.accepted_renderer, _SpecRenderer):
                 generator = self.generator_class(info, version, url, patterns, urlconf)
             else:
@@ -120,7 +137,7 @@ def get_schema_view(info=None, url=None, patterns=None, urlconf=None, public=Fal
 
             Arguments described in :meth:`.as_cached_view`.
             """
-            view = vary_on_headers('Cookie', 'Authorization')(view)
+            view = vary_on_headers("Cookie", "Authorization")(view)
             view = cache_page(cache_timeout, **cache_kwargs)(view)
             view = deferred_never_cache(view)  # disable in-browser caching
             return view
@@ -141,35 +158,43 @@ def get_schema_view(info=None, url=None, patterns=None, urlconf=None, public=Fal
             if cache_timeout != 0:
                 view = cls.apply_cache(view, cache_timeout, cache_kwargs)
             elif cache_kwargs:
-                warnings.warn("cache_kwargs ignored because cache_timeout is 0 (disabled)")
+                warnings.warn(
+                    "cache_kwargs ignored because cache_timeout is 0 (disabled)"
+                )
             return view
 
         @classmethod
         def without_ui(cls, cache_timeout=0, cache_kwargs=None):
             """
-            Instantiate this view with just JSON and YAML renderers, optionally wrapped with cache_page.
-            See https://docs.djangoproject.com/en/dev/topics/cache/.
+            Instantiate this view with just JSON and YAML renderers, optionally wrapped
+            with cache_page.  See https://docs.djangoproject.com/en/dev/topics/cache/.
 
             :param int cache_timeout: same as cache_page; set to 0 for no cache
             :param dict cache_kwargs: dictionary of kwargs to be passed to cache_page
             :return: a view instance
             """
-            return cls.as_cached_view(cache_timeout, cache_kwargs, renderer_classes=_spec_renderers)
+            return cls.as_cached_view(
+                cache_timeout, cache_kwargs, renderer_classes=_spec_renderers
+            )
 
         @classmethod
-        def with_ui(cls, renderer='swagger', cache_timeout=0, cache_kwargs=None):
+        def with_ui(cls, renderer="swagger", cache_timeout=0, cache_kwargs=None):
             """
-            Instantiate this view with a Web UI renderer, optionally wrapped with cache_page.
-            See https://docs.djangoproject.com/en/dev/topics/cache/.
+            Instantiate this view with a Web UI renderer, optionally wrapped with
+            cache_page.  See https://docs.djangoproject.com/en/dev/topics/cache/.
 
             :param str renderer: UI renderer; allowed values are ``swagger``, ``redoc``
             :param int cache_timeout: same as cache_page; set to 0 for no cache
             :param dict cache_kwargs: dictionary of kwargs to be passed to cache_page
             :return: a view instance
             """
-            assert renderer in UI_RENDERERS, "supported default renderers are " + ", ".join(UI_RENDERERS)
+            assert renderer in UI_RENDERERS, (
+                "supported default renderers are " + ", ".join(UI_RENDERERS)
+            )
             renderer_classes = UI_RENDERERS[renderer] + _spec_renderers
 
-            return cls.as_cached_view(cache_timeout, cache_kwargs, renderer_classes=renderer_classes)
+            return cls.as_cached_view(
+                cache_timeout, cache_kwargs, renderer_classes=renderer_classes
+            )
 
     return SchemaView
