@@ -6,7 +6,7 @@ from .models import Identity, Person
 class IdentitySerializer(serializers.ModelSerializer):
     class Meta:
         model = Identity
-        fields = '__all__'
+        fields = "__all__"
 
 
 class PersonSerializer(serializers.ModelSerializer):
@@ -14,10 +14,10 @@ class PersonSerializer(serializers.ModelSerializer):
 
     class Meta:
         model = Person
-        fields = '__all__'
+        fields = "__all__"
 
     def create(self, validated_data):
-        identity = Identity(**validated_data['identity'])
+        identity = Identity(**validated_data["identity"])
         identity.save()
-        validated_data['identity'] = identity
+        validated_data["identity"] = identity
         return super().create(validated_data)
