@@ -13,13 +13,17 @@ class VersionedSchemaView(SchemaView):
 
 
 schema_patterns = [
-    re_path(r'swagger\.(?P<format>json|yaml)$', VersionedSchemaView.without_ui(), name='ns-schema')
+    re_path(
+        r"swagger\.(?P<format>json|yaml)$",
+        VersionedSchemaView.without_ui(),
+        name="ns-schema",
+    )
 ]
 
 
 urlpatterns = required_urlpatterns + [
-    path(VERSION_PREFIX_NS + "v1.0/snippets/", include(ns_version1, namespace='1.0')),
+    path(VERSION_PREFIX_NS + "v1.0/snippets/", include(ns_version1, namespace="1.0")),
     path(VERSION_PREFIX_NS + "v2.0/snippets/", include(ns_version2)),
-    path(VERSION_PREFIX_NS + "v1.0/", include((schema_patterns, '1.0'))),
-    path(VERSION_PREFIX_NS + "v2.0/", include((schema_patterns, '2.0'))),
+    path(VERSION_PREFIX_NS + "v1.0/", include((schema_patterns, "1.0"))),
+    path(VERSION_PREFIX_NS + "v2.0/", include((schema_patterns, "2.0"))),
 ]
